# -*- coding: utf-8 -*-
"""
Created on Tue Jan 11 15:35:26 2022

@author: Zijian Wan
"""
import copy
import pandas as pd
import seaborn as sns
import matplotlib.pyplot as plt
import matplotlib.ticker as mtick


# read data
cout_df = pd.read_csv("CheckOuts_Monthly_by_Topic_2012-2021.csv")
cats = cout_df.columns.to_list()[2:]


# year-month str
for rcdi in range(len(cout_df)):
    cout_df.loc[rcdi, 'ym'] = (str(cout_df.loc[rcdi, 'years']) + '-' + 
                               str(cout_df.loc[rcdi, 'months']))
del rcdi


# set plot theme for asthetics
sns.set_theme()
sns.set_context("talk")


# plot data by category
plt.figure(figsize=(30,20))
for cati in cats:
    plt.plot(cout_df['ym'], cout_df[cati], label=cati)
del cati
plt.xticks(fontsize=20, rotation=45)
plt.yticks(fontsize=20)
plt.xlabel('Time', fontsize=25)
plt.ylabel('Number of checkouts', fontsize=25)
plt.legend(loc='best', fontsize=20)
plt.title('Monthly checkouts by Dewey classification categories', fontsize=40)
ax = plt.gca()
ax.set_xticks(ax.get_xticks()[::6])
plt.show()


# compute change percentages of checkouts 
# using the first record (2012-01) as the baseline
cout_change_df = copy.deepcopy(cout_df)
for cati in cats:
    for rcdi in range(len(cout_change_df)):
        if rcdi == 0:  # the 1st record
            cout_change_df.loc[rcdi, cati] = 0
        else:
            cout_change_df.loc[rcdi, cati] = (
                (cout_change_df.loc[rcdi, cati] - cout_df.loc[0, cati]) 
                / cout_df.loc[0, cati])
del cati, rcdi

# plot change percentages
plt.figure(figsize=(30,20))
for cati in cats:
    plt.plot(cout_change_df['ym'], cout_change_df[cati], label=cati)
del cati
plt.xticks(fontsize=20, rotation=45)
plt.yticks(fontsize=20)
plt.xlabel('Time', fontsize=25)
plt.ylabel('Change of checkouts (%)', fontsize=25)
plt.legend(loc='best', fontsize=20)
plt.title('Monthly checkout changes by Dewey classification categories', 
          fontsize=40)
ax = plt.gca()
ax.set_xticks(ax.get_xticks()[::6])
ax.yaxis.set_major_formatter(mtick.PercentFormatter())
plt.show()
